@@ -1095,6 +1095,9 @@ class _DictGetter(t.Generic[_BaseDictT]):
         def _unsafe_get_base_data(self) -> t.Dict[str, t.Any]:
             return copy.copy(self.__data)
 
+    def __repr__(self) -> str:
+        return '_DictGetter({!r})'.format(self.__data)
+
     def __getattr__(self, key: str) -> object:
         try:
             return self.__data[key]
