@@ -6,7 +6,9 @@ from . import (
     auto_test,
     comment,
     course,
+    file,
     group,
+    login_link,
     lti,
     site_settings,
     submission,
