@@ -26,7 +26,9 @@ if t.TYPE_CHECKING:
     from codegrade._api.auto_test import AutoTestService as _AutoTestService
     from codegrade._api.comment import CommentService as _CommentService
     from codegrade._api.course import CourseService as _CourseService
+    from codegrade._api.file import FileService as _FileService
     from codegrade._api.group import GroupService as _GroupService
+    from codegrade._api.login_link import LoginLinkService as _LoginLinkService
     from codegrade._api.lti import LTIService as _LTIService
     from codegrade._api.site_settings import (
         SiteSettingsService as _SiteSettingsService,
@@ -61,6 +63,8 @@ class _BaseClient:
         "__comment",
         "__submission",
         "__group",
+        "__login_link",
+        "__file",
         "__open_level",
     )
 
@@ -91,6 +95,8 @@ class _BaseClient:
             "_SubmissionService[_BaseClientT]"
         ] = None
         self.__group: t.Optional["_GroupService[_BaseClientT]"] = None
+        self.__login_link: t.Optional["_LoginLinkService[_BaseClientT]"] = None
+        self.__file: t.Optional["_FileService[_BaseClientT]"] = None
 
     def _get_headers(self) -> t.Mapping[str, str]:
         """Get headers to be used in all endpoints"""
@@ -225,6 +231,22 @@ class _BaseClient:
             self.__group = m.GroupService(self)
         return self.__group
 
+    @property
+    def login_link(self: _BaseClientT) -> "_LoginLinkService[_BaseClientT]":
+        if self.__login_link is None:
+            import codegrade._api.login_link as m
+
+            self.__login_link = m.LoginLinkService(self)
+        return self.__login_link
+
+    @property
+    def file(self: _BaseClientT) -> "_FileService[_BaseClientT]":
+        if self.__file is None:
+            import codegrade._api.file as m
+
+            self.__file = m.FileService(self)
+        return self.__file
+
 
 class Client(_BaseClient):
     """A class used to do unauthenticated requests to CodeGrade"""
