@@ -3,6 +3,9 @@
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
 
+from ._submission_rubric_item_data_parser import (
+    _SubmissionRubricItemDataParser,
+)
 from .about import About
 from .abstract_role import AbstractRole
 from .all_site_settings import AllSiteSettings
@@ -101,10 +104,15 @@ from .options_input_data import OptionsInputData
 from .patch_assignment_data import PatchAssignmentData
 from .patch_auto_test_data import PatchAutoTestData
 from .patch_course_data import PatchCourseData
+from .patch_grader_submission_data import PatchGraderSubmissionData
 from .patch_notification_setting_user_setting_data import (
     PatchNotificationSettingUserSettingData,
 )
+from .patch_rubric_result_submission_data import (
+    PatchRubricResultSubmissionData,
+)
 from .patch_site_settings_data import PatchSiteSettingsData
+from .patch_submission_data import PatchSubmissionData
 from .patch_tenant_data import PatchTenantData
 from .patch_ui_preference_user_setting_data import (
     PatchUiPreferenceUserSettingData,
